using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Printing;
using System.Text;
using System.Windows.Forms;
using Utilities;

namespace Ch8
{
    public partial class MainForm : Form
    {
        String fileName = "myFile.txt";
        int m_nPage = 1;
        int m_nTotalPage = 4;
        int m_nMaxPage = 4;
        Font m_fontPrinter = null;

        public MainForm()
        {
            InitializeComponent();

            m_nPage = 1;
            printPreviewControl1.StartPage = 0;
            printPreviewControl1.Rows = 1;
            printPreviewControl1.Columns = 2;
        }

        private void buttonPrint_Click(object sender, EventArgs e)
        {
            m_nPage = 1;
            this.printDocument.DocumentName = this.fileName;
            this.printDocument.Print();
        }

        private void printDocument_PrintPage(object sender, System.Drawing.Printing.PrintPageEventArgs e)
        {
            Graphics g = e.Graphics;
            Rectangle realPageBounds = PrintUtils.GetRealPageBounds(e, preview);
            Rectangle realMarginBounds = PrintUtils.GetRealMarginBounds(e, preview);

            g.DrawRectangle(Pens.Black, realPageBounds);
            g.DrawRectangle(Pens.Black, realMarginBounds);
            g.DrawString("COP4226", m_fontPrinter, Brushes.Black, realPageBounds);

            g.DrawString("Hello,\nPrinter", m_fontPrinter, Brushes.Black, realMarginBounds);
            realMarginBounds.Y += (int)(m_fontPrinter.GetHeight() * 2);
            g.DrawString("Page: " + m_nPage.ToString(), m_fontPrinter, Brushes.Black, realMarginBounds);

            using (StringFormat format = new StringFormat())
            {
                format.Alignment = StringAlignment.Far;
                format.LineAlignment = StringAlignment.Far;
                g.DrawString("FIU", m_fontPrinter, Brushes.Black, realPageBounds, format);
            }
            m_nPage++;
            e.HasMorePages = m_nPage <= m_nMaxPage;
        }

        private void buttonPreview_Click(object sender, EventArgs e)
        {
            m_nPage = 1;
            printPreviewDialog.ShowDialog();
        }

        bool preview = false;
        private void printDocument_BeginPrint(object sender, System.Drawing.Printing.PrintEventArgs e)
        {
            preview = (e.PrintAction == PrintAction.PrintToPreview);
            m_fontPrinter = new Font("Lucida Console", 72);
        }

        private void printDocument_EndPrint(object sender, System.Drawing.Printing.PrintEventArgs e)
        {
            m_fontPrinter.Dispose();
            m_fontPrinter = null;
            m_nPage = 1;
        }

        private void printPreviewControl1_KeyDown(object sender, KeyEventArgs e)
        {
            Console.Out.WriteLine("Key Down");
                
            if (e.KeyCode == Keys.PageUp)
            {
                Console.Out.WriteLine("Page Up");
                printPreviewControl1.StartPage = 3;
                printPreviewControl1.InvalidatePreview();
            }
        }

        private void buttonNext_Click(object sender, EventArgs e)
        {
            if (m_nPage < m_nTotalPage)
            {
                m_nPage++;
            }
            printPreviewControl1.StartPage = m_nPage - 1;
        }

        private void printDocument_QueryPageSettings(object sender, QueryPageSettingsEventArgs e)
        {
            e.PageSettings.Margins = new Margins(m_nMargin, m_nMargin, m_nMargin, m_nMargin);
        }

        int m_nMargin = 100;
        private void buttonMargin_Click(object sender, EventArgs e)
        {
            m_nMargin = 50;
            printPreviewControl1.InvalidatePreview();
        }

        private void buttonSetup_Click(object sender, EventArgs e)
        {
            pageSetupDialog.ShowDialog();
        }

        private void buttonDialog_Click(object sender, EventArgs e)
        {
            printDocument.PrinterSettings.FromPage = 1;
            printDocument.PrinterSettings.ToPage = m_nTotalPage;
            printDocument.PrinterSettings.MinimumPage = 1;
            printDocument.PrinterSettings.MaximumPage = m_nTotalPage;
            printDialog.AllowSomePages = true;
            if (printDialog.ShowDialog() == DialogResult.OK)
            {
                if (printDialog.PrinterSettings.PrintRange ==
                    PrintRange.SomePages)
                {
                    m_nPage = printDocument.PrinterSettings.FromPage;
                    m_nMaxPage = printDocument.PrinterSettings.ToPage;
                }
                else
                {
                    m_nPage = 1;
                    m_nMaxPage = m_nTotalPage;
                }
                this.printDocument.Print();
            }
        }



    }
}